@@ -1,4 +1,6 @@
 //p:cNvPr
+use super::super::super::StringValue;
+use super::super::super::UInt32Value;
 use writer::driver::*;
 use reader::driver::*;
 use quick_xml::Reader;
@@ -8,24 +10,24 @@ use std::io::Cursor;
 
 #[derive(Default, Debug)]
 pub struct NonVisualDrawingProperties  {
-    name: String,
-    id: String,
+    name: StringValue,
+    id: UInt32Value,
 }
 impl NonVisualDrawingProperties  {
     pub fn get_name(&self) -> &str {
-        &self.name
+        &self.name.get_value()
     }
 
     pub fn set_name<S: Into<String>>(&mut self, value:S) {
-        self.name = value.into();
+        self.name.set_value(value);
     }
 
-    pub fn get_id(&self) -> &str {
-        &self.id
+    pub fn get_id(&self) -> &u32 {
+        &self.id.get_value()
     }
 
-    pub fn set_id<S: Into<String>>(&mut self, value:S) {
-        self.id = value.into();
+    pub fn set_id(&mut self, value:u32) {
+        self.id.set_value(value);
     }
 
     pub(crate) fn set_attributes(
@@ -33,14 +35,14 @@ impl NonVisualDrawingProperties  {
         _reader:&mut Reader<std::io::BufReader<std::fs::File>>,
         e:&BytesStart
     ) {
-        &mut self.set_id(get_attribute(e, b"id").unwrap());
-        &mut self.set_name(get_attribute(e, b"name").unwrap());
+        &mut self.id.set_value_string(get_attribute(e, b"id").unwrap());
+        &mut self.name.set_value_string(get_attribute(e, b"name").unwrap());
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
         write_start_tag(writer, "xdr:cNvPr", vec![
-            ("id", &self.id),
-            ("name", &self.name),
+            ("id", &self.id.get_value_string()),
+            ("name", &self.name.get_value_string()),
         ], true);
     }
 }
