@@ -1,15 +1,14 @@
 use quick_xml::events::{Event, BytesDecl};
 use quick_xml::Writer;
-use std::io::Cursor;
-use tempdir::TempDir;
+use std::io;
 
 use ::structs::Spreadsheet;
 use super::driver::*;
 use super::XlsxError;
 
-pub(crate) fn write(spreadsheet: &Spreadsheet, dir: &TempDir, sub_dir: &str, file_name: &str) -> Result<(), XlsxError>
+pub(crate) fn write<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, arv: &mut zip::ZipWriter<W>, sub_dir: &str, file_name: &str) -> Result<(), XlsxError>
 {
-    let mut writer = Writer::new(Cursor::new(Vec::new()));
+    let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
     let _ = writer.write_event(Event::Decl(BytesDecl::new(b"1.0", Some(b"UTF-8"), Some(b"yes"))));
     write_new_line(&mut writer);
@@ -59,12 +58,7 @@ pub(crate) fn write(spreadsheet: &Spreadsheet, dir: &TempDir, sub_dir: &str, fil
     ], false);
 
     // workbookView
-    write_start_tag(&mut writer, "workbookView", vec![
-        ("xWindow", "240"),
-        ("yWindow", "105"),
-        ("windowWidth", "14805"),
-        ("windowHeight", "8010"),
-    ], true);
+    spreadsheet.get_workbook_view().write_to(&mut writer);
 
     write_end_tag(&mut writer, "bookViews");
 
@@ -119,6 +113,6 @@ pub(crate) fn write(spreadsheet: &Spreadsheet, dir: &TempDir, sub_dir: &str, fil
     ], true);
     
     write_end_tag(&mut writer, "workbook");
-    let _ = make_file_from_writer(format!("{}/{}",sub_dir,file_name).as_str(), dir, writer, Some(sub_dir)).unwrap();
+    let _ = make_file_from_writer(&file_name, arv, writer, Some(sub_dir)).unwrap();
     Ok(())
 }
