@@ -1,34 +1,29 @@
 use quick_xml::events::{Event, BytesDecl};
 use quick_xml::Writer;
-use std::io::Cursor;
-use tempdir::TempDir;
-use std::collections::BTreeMap;
+use std::io;
 use std::collections::BTreeSet;
-
 use ::structs::Spreadsheet;
 use ::structs::Worksheet;
 use ::structs::SharedStringTable;
 use ::structs::Stylesheet;
-use super::super::helper::coordinate::*;
 use super::driver::*;
 use super::XlsxError;
 
 const SUB_DIR: &'static str = "xl/worksheets";
 
-pub(crate) fn write(
+pub(crate) fn write<W: io::Seek + io::Write>(
     spreadsheet: &Spreadsheet,
     sheet_index: &usize,
     shared_string_table: &mut SharedStringTable,
     stylesheet: &mut Stylesheet,
-    dir: &TempDir
+    arv: &mut zip::ZipWriter<W>,
 ) -> Result<(), XlsxError> 
 {
-    let is_selected = spreadsheet.get_active_sheet_index() == sheet_index;
     let has_macros = spreadsheet.get_has_macros();
     let sheet_no = sheet_index + 1;
 
     let file_name = format!("sheet{}.xml", &sheet_no);
-    let mut writer = Writer::new(Cursor::new(Vec::new()));
+    let mut writer = Writer::new(io::Cursor::new(Vec::new()));
 
     {
         let worksheet = spreadsheet.get_sheet(sheet_index.clone()).unwrap();
@@ -99,22 +94,7 @@ pub(crate) fn write(
        ], false);
 
         // sheetView
-        let has_active_cell = worksheet.get_active_cell() != "";
-        let mut attributes: Vec<(&str, &str)> = Vec::new();
-        if is_selected == true {
-            attributes.push(("tabSelected", "1"));
-        }
-        attributes.push(("workbookViewId", "0"));
-        write_start_tag(&mut writer, "sheetView", attributes, !has_active_cell);
-
-        if has_active_cell {
-            // selection
-            write_start_tag(&mut writer, "selection", vec![
-                ("activeCell", worksheet.get_active_cell()),
-                ("sqref", worksheet.get_active_cell()),
-            ], true);
-            write_end_tag(&mut writer, "sheetView");
-        }
+        worksheet.get_sheet_view().write_to(&mut writer);
 
         write_end_tag(&mut writer, "sheetViews");
 
@@ -124,147 +104,39 @@ pub(crate) fn write(
             ("x14ac:dyDescent", "0.15"),
         ], true);
 
-        if worksheet.get_column_dimensions().len() > 0 {
-            // cols
-            write_start_tag(&mut writer, "cols", vec![], false);
-
-            // col
-            for cols in worksheet.get_column_dimensions() {
-                let mut attributes: Vec<(&str, &str)> = Vec::new();
-                let min = cols.get_col_num_start().to_string();
-                let max = cols.get_col_num_end().to_string();
-                let width = cols.get_width().to_string();
-                attributes.push(("min", min.as_str()));
-                attributes.push(("max", max.as_str()));
-                attributes.push(("width", width.as_str()));
-                if cols.get_best_fit() == &true {
-                    attributes.push(("bestFit", "1"));
-                }
-                attributes.push(("customWidth", "1"));
-                write_start_tag(&mut writer, "col", attributes, true);
-            }
-
-            write_end_tag(&mut writer, "cols");
-        }
-
-        let mut cells_by_row = BTreeMap::new();
-        let coordinates = worksheet.get_coordinates();
-        for coordinate in &coordinates {
-            let csf = coordinate_from_string(coordinate.as_str());
-            let row_name:usize = csf.get(1).unwrap().unwrap().parse().unwrap();
-            let cells = match cells_by_row.get_mut(&row_name) {
-                Some(v) => { v },
-                None => {
-                    cells_by_row.insert(row_name.clone(), Vec::new());
-                    cells_by_row.get_mut(&row_name).unwrap()
-                }
-            };
-            cells.push(coordinate);
-        }
+        // cols
+        worksheet.get_column_dimensions_crate().write_to(&mut writer, stylesheet);
 
         // sheetData
         let has_sheet_data = worksheet.get_row_dimensions().len() > 0;
         write_start_tag(&mut writer, "sheetData", vec![], !has_sheet_data);
 
         for (row_num, row) in worksheet.get_row_dimensions_to_b_tree_map() {
-
-            // cells and styles
+            // cells
             let cells = worksheet.get_collection_by_row(&row_num);
-            let styles = worksheet.get_style_collection_by_row(&row_num);
-            let mut col_num_list:BTreeSet<usize> = BTreeSet::new();
+            let mut col_num_list:BTreeSet<u32> = BTreeSet::new();
             for (col_num, _) in &cells {
                 col_num_list.insert(col_num.clone());
             }
-            for (col_num, _) in &styles {
-                col_num_list.insert(col_num.clone());
-            }
 
             // row
             let include_cell = col_num_list.len() > 0;
-            let mut attributes: Vec<(&str, &str)> = Vec::new();
-            let r_string = row_num.to_string();
-            attributes.push(("r", &r_string));
             let fist_num = match col_num_list.iter().next() {
                 Some(col_num) => col_num,
-                None => &0usize
+                None => &0u32
             };
             let last_num = match col_num_list.iter().last() {
                 Some(col_num) => col_num,
-                None => &0usize
+                None => &0u32
             };
             let spans = format!("{}:{}", fist_num, last_num);
-            if include_cell {
-                attributes.push(("spans", &spans));
+            row.write_to(&mut writer, stylesheet, spans, !include_cell);
+
+            // c
+            for (_, cell) in cells {
+                cell.write_to(&mut writer, shared_string_table, stylesheet);
             }
-            let ht = row.get_height().to_string();
-            if row.get_height() != &0f32 {
-                attributes.push(("ht", &ht));
-            }
-            if row.get_thick_bot() == &true {
-                attributes.push(("thickBot", "1"));
-            }
-            if row.get_custom_height() == &true {
-                attributes.push(("customHeight", "1"));
-            }
-            let dy_descent = row.get_descent().to_string();
-            attributes.push(("x14ac:dyDescent", &dy_descent));
-            write_start_tag(&mut writer, "row", attributes, !include_cell);
 
-            for col_num in col_num_list {
-                let cell = &cells.get(&col_num);
-                let style = &styles.get(&col_num);
-
-                let coordinate = coordinate_from_index(&col_num, &row_num);
-                let xf_index_str:String;
-                let mut attributes: Vec<(&str, &str)> = Vec::new();
-                attributes.push(("r", &coordinate));
-
-                match style {
-                    Some(v) => {
-                        let xf_index = stylesheet.set_style(v);
-                        xf_index_str = xf_index.to_string();
-                        attributes.push(("s", &xf_index_str));
-                    },
-                    None => {}
-                }
-
-                match cell {
-                    Some(c) => {
-                        if c.get_data_type() == "s" || c.get_data_type() == "b" {
-                            attributes.push(("t", c.get_data_type()));
-                        }
-                        write_start_tag(&mut writer, "c", attributes, false);
-
-                        // f
-                        if c.get_formula() != "" {
-                            write_start_tag(&mut writer, "f", vec![], false);
-                            write_text_node(&mut writer, c.get_formula());
-                            write_end_tag(&mut writer, "f");
-                        }
-
-                        // v
-                        write_start_tag(&mut writer, "v", vec![], false);
-                        
-                        match c.get_data_type() {
-                            "s" => {
-                                let val_index = shared_string_table.set_cell(&c);
-                                write_text_node(&mut writer, val_index.to_string());
-                            },
-                            "b" => {
-                                let upper_value = c.get_value().to_uppercase();
-                                let prm = if upper_value == "TRUE" {"1"} else {"0"};
-                                write_text_node(&mut writer, prm);
-                            },
-                            _ => write_text_node(&mut writer, c.get_value()),
-                        }
-                        write_end_tag(&mut writer, "v");
-                        write_end_tag(&mut writer, "c");
-                    },
-                    None => {
-                        write_start_tag(&mut writer, "c", attributes, true);
-                    }
-                }
-            }
             if include_cell {
                 write_end_tag(&mut writer, "row");
             }
@@ -307,7 +179,7 @@ pub(crate) fn write(
 
         // conditionalFormatting
         for conditional_formatting in worksheet.get_conditional_styles_collection() {
-            let coordinates = conditional_formatting.get_sqref();
+            let coordinates = conditional_formatting.get_sequence_of_references().get_sqref();
             write_start_tag(&mut writer, "conditionalFormatting", vec![
                 ("sqref", &coordinates),
             ], false);
@@ -446,7 +318,7 @@ pub(crate) fn write(
     }
     
     write_end_tag(&mut writer, "worksheet");
-    let _ = make_file_from_writer(format!("{}/{}", SUB_DIR, file_name).as_str(), dir, writer, Some(SUB_DIR)).unwrap();
+    let _ = make_file_from_writer(&file_name, arv, writer, Some(SUB_DIR)).unwrap();
     Ok(())
 }
 
