@@ -12,24 +12,23 @@ fn read_and_wite() {
     let b5_value = book.get_sheet(0).unwrap().get_value("B5");
     assert_eq!(" ", b5_value);
 
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value_by_column_and_row(2, 20));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B20"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B21"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B22"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B23"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B24"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B25"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B26"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B27"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B28"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B29"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B30"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B31"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B32"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B33"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B34"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B35"));
-    dbg!(book.get_sheet(0).unwrap().get_formatted_value("B36"));
+    assert_eq!("1.0000",            book.get_sheet(0).unwrap().get_formatted_value_by_column_and_row(2, 20));
+    assert_eq!("$3,333.0000",       book.get_sheet(0).unwrap().get_formatted_value("B21"));
+    assert_eq!("$ 333.00",          book.get_sheet(0).unwrap().get_formatted_value("B22"));
+    assert_eq!("2020年3月",         book.get_sheet(0).unwrap().get_formatted_value("B23"));
+    assert_eq!("2:33 pm",           book.get_sheet(0).unwrap().get_formatted_value("B24"));
+    assert_eq!("5.00%",             book.get_sheet(0).unwrap().get_formatted_value("B25"));
+    assert_eq!("1/2",               book.get_sheet(0).unwrap().get_formatted_value("B26"));
+    assert_eq!("12/15/2020 14:01",  book.get_sheet(0).unwrap().get_formatted_value("B27"));
+    assert_eq!("444",               book.get_sheet(0).unwrap().get_formatted_value("B28"));
+    assert_eq!("14-Dec-20",         book.get_sheet(0).unwrap().get_formatted_value("B29"));
+    assert_eq!("2020年10月1日",     book.get_sheet(0).unwrap().get_formatted_value("B30"));
+    assert_eq!("1.2345",            book.get_sheet(0).unwrap().get_formatted_value("B31"));
+    assert_eq!("1.2",               book.get_sheet(0).unwrap().get_formatted_value("B32"));
+    assert_eq!("12,345,675,544.00", book.get_sheet(0).unwrap().get_formatted_value("B33"));
+    assert_eq!("1.235",             book.get_sheet(0).unwrap().get_formatted_value("B34"));
+    assert_eq!("1",                 book.get_sheet(0).unwrap().get_formatted_value("B35"));
+    assert_eq!("",                  book.get_sheet(0).unwrap().get_formatted_value("B36"));
 
     let _ = book.get_sheet_by_name_mut("Sheet1").unwrap().get_cell_mut("A1")
     .set_value("49046881.119999997");
@@ -38,7 +37,7 @@ fn read_and_wite() {
     .get_number_format_mut().set_format_code(umya_spreadsheet::NumberingFormat::FORMAT_NUMBER_COMMA_SEPARATED1);
 
     let value =  book.get_sheet_by_name_mut("Sheet1").unwrap().get_formatted_value("A1");
-    dbg!(&value);
+    assert_eq!("49,046,881.12", &value);
 
     // writer
     let path = std::path::Path::new("./tests/result_files/bbb.xlsx");
@@ -109,10 +108,18 @@ fn new_and_wite() {
     let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_cell_by_column_and_row(2, 2).unwrap().get_value();
     assert_eq!("1", a1_value);
 
+    book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_by_column_and_row_mut(2, 2).set_value_from_i32_ref(&1);
+    let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_cell_by_column_and_row(2, 2).unwrap().get_value();
+    assert_eq!("1", a1_value);
+
     book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_by_column_and_row_mut(3, 3).set_value_from_bool(true);
     let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_cell_by_column_and_row(3, 3).unwrap().get_value();
     assert_eq!("TRUE", a1_value);
 
+    book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_by_column_and_row_mut(3, 3).set_value_from_bool_ref(&true);
+    let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_cell_by_column_and_row(3, 3).unwrap().get_value();
+    assert_eq!("TRUE", a1_value);
+
     // add bottom border.
     book.get_sheet_by_name_mut("Sheet2").unwrap().get_style_mut("A1")
     .get_borders_mut()
